@@ -30,43 +30,6 @@ class IssuesTotal(EmbeddedDocument):
     code_errors = IntField(default=0)
     devops_warnings = IntField(default=0)
     devops_errors = IntField(default=0)
-    
-
-class RepoEvents(Document):
-    """The repository events collection model.
-
-    Attributes:
-        event_type (StringField): The GitHub event type https://developer.github.com/v3/activity/event_types
-        organization (StringField): The organization name of the GitHub repo.
-        repository (StringField): The name of the GitHub repo.
-        timestamp (DateTimeField): The datetime timestamp of the event.
-    """
-
-    meta = {'allow_inheritance': True}
-
-    # Static list of valid event types
-    valid_event_types = ("UserEvent", "CommitEvent")
-
-    # Crawler fields
-    event_type = StringField(required=True, choices=valid_event_types)
-    organization = StringField(required=True)
-    repository = StringField(required=True)
-    timestamp = DateTimeField(required=True)
-
-    # Commit fields
-    sha = StringField(required=True)
-    ref = StringField(required=True, null=True)
-    user = StringField(required=True)
-
-    # PR Details
-    additions = IntField(default=0)
-    deletions = IntField(default=0)
-    total = IntField(default=0)
-    commit_files = ListField()
-
-    # KPIs
-    development_kpi = EmbeddedDocumentField(DevelopmentKPI)
-    velocity_kpi = EmbeddedDocumentField(VelocityKPI)
 
 
 class LinterScanEvent(EmbeddedDocument):
@@ -132,11 +95,10 @@ class InfrastructureKPI(EmbeddedDocument):
 
 class UserCommit(EmbeddedDocument):
     ''' User Commit '''
-    user = StringField(required=True)
     sha = StringField(required=True)
 
 
-class UserEvents(Document):
+class UserEvent(Document):
     """The repository events collection model.
 
     Attributes:
@@ -148,11 +110,7 @@ class UserEvents(Document):
 
     meta = {'allow_inheritance': True}
 
-    # Static list of valid event types
-    valid_event_types = ("UserEvent", "CommitEvent")
-
     # Crawler fields
-    event_type = StringField(required=True, choices=valid_event_types)
     organization = StringField(required=True)
     repository = StringField(required=True)
     timestamp = DateTimeField(required=True)
@@ -173,7 +131,7 @@ class UserEvents(Document):
     velocity_kpi = EmbeddedDocumentField(VelocityKPI)
 
 
-class CommitEvent(RepoEvents):
+class PrEvent(Document):
     """The GitHub commit events model.
 
     Attributes:
@@ -183,6 +141,27 @@ class CommitEvent(RepoEvents):
         filename_flags (ListField, optional): Flags that matched the filename rules.
         LinterScanEvents (Document): A sub-document for static analysis events.
     """
+    meta = {'allow_inheritance': True}
+
+    # Crawler fields
+    organization = StringField(required=True)
+    repository = StringField(required=True)
+    timestamp = DateTimeField(required=True)
+
+    # Commit fields
+    sha = StringField(required=True)
+    ref = StringField(required=True, null=True)
+    user = StringField(required=True)
+
+    # PR Details
+    additions = IntField(default=0)
+    deletions = IntField(default=0)
+    total = IntField(default=0)
+    commit_files = ListField()
+
+    # KPIs
+    development_kpi = EmbeddedDocumentField(DevelopmentKPI)
+    velocity_kpi = EmbeddedDocumentField(VelocityKPI)
 
     # User Contributions
     users_commits = EmbeddedDocumentListField(UserCommit)
